using PkmnLib.Dynamic.Models;

namespace PkmnLib.Dynamic.Events;

/// <summary>
/// Event triggered when a Pokemon is healed.
/// </summary>
public class HealEvent : IEventData
{
    /// <inheritdoc cref="HealEvent"/>
    public HealEvent(IPokemon pokemon, uint previousHealth, uint newHealth)
    {
        Pokemon = pokemon;
        PreviousHealth = previousHealth;
        NewHealth = newHealth;
    }

    /// <summary>
    /// The Pokemon that was healed.
    /// </summary>
    public IPokemon Pokemon { get; }

    /// <summary>
    /// The previous health of the Pokemon.
    /// </summary>
    public uint PreviousHealth { get; }

    /// <summary>
    /// The new health of the Pokemon.
    /// </summary>
    public uint NewHealth { get; }


    /// <inheritdoc />
    public EventBatchId BatchId { get; init; } = new();
}